==> dxcr-vue-cesium-0.0.1.tgz: package/lib/extend/flood/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.1.6
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2020, zouyaoji <370681295@qq.com>
 */
import _Object$defineProperties from '@babel/runtime-corejs2/core-js/object/define-properties';
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import cmp from '../../mixins/virtualCmp';
import { makeColor } from '../../utils/cesiumHelpers';

var script = {
  name: 'vc-analytics-flood',
  data: function data() {
    return {
      geometry: null,
      attributes: null,
      extrudedHeight: 0.1,
      flooding: false,
      appearance: null,
      nowaiting: true
    };
  },
  mixins: [cmp],
  props: {
    minHeight: {
      type: Number,
      default: 0
    },
    maxHeight: Number,
    polygonHierarchy: Array,
    speed: {
      type: Number,
      default: 10
    },
    color: {
      type: Object | Array | String,
      default: 'rgba(40,150,200,0.6)'
    }
  },
  watch: {
    flooding: function flooding(val) {
      var listener = this.$listeners['activeEvt'];

      if (val) {
        if (this.floodDone) {
          this.extrudedHeight = this.extrudedHeight >= this.minHeight ? this.minHeight : 0.1;
          this.floodDone = false;
        }

        this._mounted = true;
        this.viewer.clock.onTick.addEventListener(this.onTick);
        listener && this.$emit('activeEvt', {
          isActive: val
        });
      } else {
        this.viewer.clock.onTick.removeEventListener(this.onTick);
        listener && this.$emit('activeEvt', {
          isActive: val
        });
      }
    },
    minHeight: function minHeight(val) {
      this.extrudedHeight = val;
    }
  },
  methods: {
    createCesiumObject: function createCesiumObject() {
      var _this = this;

      var Cesium, minHeight, color;
      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              Cesium = this.Cesium, minHeight = this.minHeight, color = this.color;
              this.attributes = {
                // eslint-disable-next-line new-cap
                color: Cesium.ColorGeometryInstanceAttribute.fromColor(makeColor(color))
              };
              this.extrudedHeight = minHeight;
              return _context.abrupt("return", this.$refs.primitive.createPromise.then(function (_ref) {
                var Cesium = _ref.Cesium,
                    viewer = _ref.viewer,
                    cesiumObject = _ref.cesiumObject;

                if (!_this.$refs.primitive._mounted) {
                  return _this.$refs.primitive.load().then(function (_ref2) {
                    var Cesium = _ref2.Cesium,
                        viewer = _ref2.viewer,
                        cesiumObject = _ref2.cesiumObject;
                    return cesiumObject;
                  });
                } else {
                  return cesiumObject;
                }
              }));

            case 4:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    },
    onTick: function onTick() {
      var maxHeight = this.maxHeight,
          speed = this.speed;

      if (this.extrudedHeight < maxHeight) {
        this.extrudedHeight = this.extrudedHeight + speed;
      } else {
        this.floodDone = true;
        this.flooding = false;
      }
    },
    clear: function clear() {},
    mount: function mount() {
      return _regeneratorRuntime.async(function mount$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              return _context2.abrupt("return", true);

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      });
    },
    unmount: function unmount() {
      return _regeneratorRuntime.async(function unmount$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              this.extrudedHeight = this.minHeight;
              this.flooding = false;
              this.$refs.primitive && this.$refs.primitive.unload();

            case 3:
            case "end":
              return _context3.stop();
          }
        }
      }, null, this);
    }
  },
  created: function created() {
    var _this2 = this;

    _Object$defineProperties(this, {
      floodObject: {
        enumerable: true,
        get: function get() {
          return _this2.$services && _this2.cesiumObject;
        }
      }
    });
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name,
    staticStyle: {
      "display": "none !important"
    }
  }, [_c('vc-primitive-classification', {
    ref: "primitive",
    attrs: {
      "appearance": _vm.appearance,
      "asynchronous": false,
      "show": _vm.extrudedHeight !== 0 && _vm.extrudedHeight !== ''
    }
  }, [_c('vc-instance-geometry', {
    attrs: {
      "attributes": _vm.attributes,
      "geometry": _vm.geometry
    },
    on: {
      "update:geometry": function updateGeometry($event) {
        _vm.geometry = $event;
      }
    }
  }, [_c('vc-geometry-polygon', {
    attrs: {
      "extrudedHeight": _vm.extrudedHeight,
      "polygonHierarchy": _vm.polygonHierarchy
    }
  })], 1)], 1)], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcFlood.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var CesiumFlood = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(CesiumFlood.name, CesiumFlood);
}

export default plugin;
export { CesiumFlood, plugin as install };

==> dxcr-vue-cesium-0.0.2.tgz: package/lib/extend/flood/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.2.0
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2021, zouyaoji <370681295@qq.com>
 */
import _Object$defineProperties from '@babel/runtime-corejs2/core-js/object/define-properties';
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import cmp from '../../mixins/virtualCmp';
import { makeColor } from '../../utils/cesiumHelpers';
import * as ClassificationPrimitive from '../../primitive/classification';
import * as GeometryInstance from '../../geometryInstance';
import * as PolygonGeometry from '../../geometryInstance/polygon';

var script = {
  name: 'vc-analytics-flood',
  data: function data() {
    return {
      geometry: null,
      attributes: null,
      extrudedHeight: 0.1,
      flooding: false,
      appearance: null,
      nowaiting: true
    };
  },
  mixins: [cmp],
  props: {
    minHeight: {
      type: Number,
      default: 0
    },
    maxHeight: Number,
    polygonHierarchy: Array,
    speed: {
      type: Number,
      default: 10
    },
    color: {
      type: [Object, Array, String],
      default: 'rgba(40,150,200,0.6)'
    }
  },
  watch: {
    flooding: function flooding(val) {
      var listener = this.$listeners.activeEvt;

      if (val) {
        if (this.floodDone) {
          this.extrudedHeight = this.extrudedHeight >= this.minHeight ? this.minHeight : 0.1;
          this.floodDone = false;
        }

        this._mounted = true;
        this.viewer.clock.onTick.addEventListener(this.onTick);
        listener && this.$emit('activeEvt', {
          isActive: val
        });
      } else {
        this.viewer.clock.onTick.removeEventListener(this.onTick);
        listener && this.$emit('activeEvt', {
          isActive: val
        });
      }
    },
    minHeight: function minHeight(val) {
      this.extrudedHeight = val;
    }
  },
  methods: {
    createCesiumObject: function createCesiumObject() {
      var _this = this;

      var Cesium, minHeight, color;
      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              Cesium = this.Cesium, minHeight = this.minHeight, color = this.color;
              this.attributes = {
                color: Cesium.ColorGeometryInstanceAttribute.fromColor(makeColor(color))
              };
              this.extrudedHeight = minHeight;
              return _context.abrupt("return", this.$refs.primitive.createPromise.then(function (_ref) {
                var Cesium = _ref.Cesium,
                    viewer = _ref.viewer,
                    cesiumObject = _ref.cesiumObject;

                if (!_this.$refs.primitive._mounted) {
                  return _this.$refs.primitive.load().then(function (_ref2) {
                    var Cesium = _ref2.Cesium,
                        viewer = _ref2.viewer,
                        cesiumObject = _ref2.cesiumObject;
                    return cesiumObject;
                  });
                } else {
                  return cesiumObject;
                }
              }));

            case 4:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    },
    onTick: function onTick() {
      var maxHeight = this.maxHeight,
          speed = this.speed;

      if (this.extrudedHeight < maxHeight) {
        this.extrudedHeight = this.extrudedHeight + speed;
      } else {
        this.floodDone = true;
        this.flooding = false;
      }
    },
    clear: function clear() {},
    mount: function mount() {
      return _regeneratorRuntime.async(function mount$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              return _context2.abrupt("return", true);

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      });
    },
    unmount: function unmount() {
      return _regeneratorRuntime.async(function unmount$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              this.extrudedHeight = this.minHeight;
              this.flooding = false;
              this.$refs.primitive && this.$refs.primitive.unload();

            case 3:
            case "end":
              return _context3.stop();
          }
        }
      }, null, this);
    }
  },
  created: function created() {
    var _this2 = this;

    _Object$defineProperties(this, {
      floodObject: {
        enumerable: true,
        get: function get() {
          return _this2.$services && _this2.cesiumObject;
        }
      }
    });
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name,
    staticStyle: {
      "display": "none !important"
    }
  }, [_c('vc-primitive-classification', {
    ref: "primitive",
    attrs: {
      "appearance": _vm.appearance,
      "asynchronous": false,
      "show": _vm.extrudedHeight !== 0 && _vm.extrudedHeight !== ''
    }
  }, [_c('vc-instance-geometry', {
    attrs: {
      "attributes": _vm.attributes,
      "geometry": _vm.geometry
    },
    on: {
      "update:geometry": function updateGeometry($event) {
        _vm.geometry = $event;
      }
    }
  }, [_c('vc-geometry-polygon', {
    attrs: {
      "extrudedHeight": _vm.extrudedHeight,
      "polygonHierarchy": _vm.polygonHierarchy
    }
  })], 1)], 1)], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcFlood.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var VcFlood = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.use(ClassificationPrimitive);
  Vue.use(GeometryInstance);
  Vue.use(PolygonGeometry);
  Vue.component(VcFlood.name, VcFlood);
}

export default plugin;
export { VcFlood, plugin as install };
